@@ -1,5 +1,10 @@
 package t::Object::WithNew::Inherited;
-use base 't::Object::WithNew';
+
+BEGIN {
+    require t::Object::WithNew;
+    @t::Object::WithNew::Inherited::ISA = 't::Object::WithNew';
+}
+
 use Class::InsideOut qw/ :std /;
 
 private age => my %age;
